==> IwPopupManager-0.3.1.tar.gz: lang/en_US.php <==
<?php
 $lang['friendlyname'] = 'Popup Manager';
 $lang['admindescription'] = 'A module for managing and displaying popups';
 
 $lang['add_popup'] = 'New Popup';
 $lang['edit'] = 'Edit';
 $lang['syntax'] = 'Syntax';
 
 $lang['popup_saved'] = 'This popup is now saved';
 $lang['submit'] = 'Submit';
 $lang['cancel'] = 'Cancel';
 $lang['name'] = 'Name';
 $lang['content'] = 'Content';
 $lang['active'] = 'Active';
 $lang['description'] = 'Description';
 
 $lang['yes'] = 'Yes';
 $lang['no'] = 'No';
 
 $lang['delete'] = 'Delete this';
 $lang['confirm_delete'] = 'Are you sure that you want to delete this popup record?';
 $lang['popup_deleted'] = 'This popup is now deleted';
 $lang['close'] = 'Close';
 $lang['hideafter'] = 'Hide after';
 $lang['hidefor'] = 'Hide from user after showing 1x for';
 $lang['seconds'] = 'seconds';
 $lang['hours'] = 'hours';
 $lang['pause_description'] = '(0 = does not hide automaticly)';
 $lang['duration_description'] = '(0 = show always)';
 $lang['set_by_cookie'] = '(checked by cookie)'; 
 $lang['disabled'] = 'Disabled';
 $lang['timer'] = 'Time'; 
 
 $lang['help'] = <<<EOF
<h3>How to use Popup Manager</h3>
<p>Popup Manager allows you to create popups that open when a site or page is opened.</p>
<p>The module name is IwPopupManager and it is the first module I wrote for CMS Made Simple.</br>
<br/>
The module will be expanded with more features in the (near) future. The next features are planned :<br/>
<ul>
<li>Startdate : At what date will the popup be shown.</li>
<li>Enddata : At what date will the popup stop to be shown</li>
<li>Style : How will the popup appear and disappear / Transistion style.</li>
<li>Colors : Set the colors of the borders, background and text.</li>
<li>Position : Where will the popup appear (left, top, center, bottom)</li>
</ul>
<br>
<p>To use the Popup Manger, simple open the Popup Manager which can be found under Content, create a popup and check the tag shown in the line after the popup. 
Enter this tag in your site template (the popup will be show on every page) or on the page where you want to show the popup. Because you can create multiple popups, eacht page can have its own popup if you want. 
It is not wise to put more then one popup on a page as that wil not work correctly (yet).</p>
<br/>
<p>Example :<br>
If you want to show the popup only on the frontpage enter the tag {cms_module module=IwPopupManager id=2} somewhere on the frontpage content.<br/>
The position of the tag is not important as the popup will always be shown in the center of the window for now.</p>
<br /><br />
NOTE: As of version 0.3 this module uses functional cookies. Please indicate on your website (in accordance with GDPR) that functional cookies are used.<br/>
<br />
<p>As said, this is my first module I created for CMS Made Simple and there is still a lot to learn.<br/>
If you have ideas to make this module better, please let me know</p>
EOF;
 ?>

==> IwPopupManager-0.4.tar.gz: lang/en_US.php <==
<?php
 $lang['friendlyname'] = 'Popup Manager';
 $lang['admindescription'] = 'A module for managing and displaying popups';
 
 $lang['add_popup'] = 'New Popup';
 $lang['edit'] = 'Edit';
 $lang['syntax'] = 'Syntax';
 
 $lang['popup_saved'] = 'This popup is now saved';
 $lang['submit'] = 'Submit';
 $lang['cancel'] = 'Cancel';
 $lang['name'] = 'Name';
 $lang['content'] = 'Content';
 $lang['active'] = 'Active';
 $lang['description'] = 'Description';
 
 $lang['yes'] = 'Yes';
 $lang['no'] = 'No';
 
 $lang['delete'] = 'Delete this';
 $lang['confirm_delete'] = 'Are you sure that you want to delete this popup record?';
 $lang['popup_deleted'] = 'This popup is now deleted';
 $lang['close'] = 'Close';
 $lang['hideafter'] = 'Hide after';
 $lang['hidefor'] = 'Hide from user after showing 1x for';
 $lang['seconds'] = 'seconds';
 $lang['hours'] = 'hours';
 $lang['pause_description'] = '(0 = does not hide automaticly)';
 $lang['duration_description'] = '(0 = show always)';
 $lang['set_by_cookie'] = '(checked by cookie)'; 
 $lang['disabled'] = 'Disabled';
 $lang['timer'] = 'Time'; 
 $lang['style'] = 'Style';
 $lang['fadein-fadeout'] = 'Fadein / Fadeout';
 $lang['zoomin-zoomout'] = 'Zoom in / Zoom out';
 $lang['top-to-bottom'] = 'Top to bottom';
 $lang['bottom-to-top'] = 'Bottom to top';
 $lang['left-to-right'] = 'Left to right';
 $lang['right-to-left'] = 'Right to Left';
 
 $lang['help'] = <<<EOF
<h3>How to use Popup Manager</h3>
<p>Popup Manager allows you to create popups that open when a site or page is opened.</p>
<p>The module name is IwPopupManager and it is the first module I wrote for CMS Made Simple.</br>
<br/>
The module will be expanded with more features in the (near) future. The next features are planned :<br/>
<ul>
<li>Startdate : At what date will the popup be shown.</li>
<li>Enddata : At what date will the popup stop to be shown</li>
<li>Colors : Set the colors of the borders, background and text.</li>
<li>Position : Where will the popup appear (left, top, center, bottom)</li>
</ul>
<br>
<p>To use the Popup Manger, simple open the Popup Manager which can be found under Content, create a popup and check the tag shown in the line after the popup. 
Enter this tag in your site template (the popup will be show on every page) or on the page where you want to show the popup. Because you can create multiple popups, eacht page can have its own popup if you want. 
It is not wise to put more then one popup on a page as that wil not work correctly (yet).</p>
<br/>
<p>Example :<br>
If you want to show the popup only on the frontpage enter the tag {cms_module module=IwPopupManager id=2} somewhere on the frontpage content.<br/>
The position of the tag is not important as the popup will always be shown in the center of the window for now.</p>
<br /><br />
NOTE: As of version 0.3 this module uses functional cookies. Please indicate on your website (in accordance with GDPR) that functional cookies are used.<br/>
<br />
<p>As said, this is my first module I created for CMS Made Simple and there is still a lot to learn.<br/>
If you have ideas to make this module better, please let me know</p>
EOF;
 ?>
